defmodule Indian.Cli do

  @default_port 8080
  @default_bound_address :any
  @default_log_level "info"
  
  def usage(msg \\ "") do
    IO.puts("Usage: indian [--bind=IP-ADDRESS] [--port=NUMBER] [--level=LOG-LEVEL]")
    if msg != "" do
      IO.puts(msg)
    end
    exit("Wrong usage")
  end
  
  def main(argv) do
    result =
      OptionParser.parse(argv,
	strict: [bind: :string, port: :integer, level: :string]
      )
    options =
      case result do
	{_, [_ | _], _} -> usage("Extra remaining arguments after options")
	{_, _, invalid} when invalid != [] -> usage("Invalid option(s): #{inspect(invalid)}")
	{opts, _, _} -> opts
	_ -> usage("Unknown error") # Should not happen
      end

    bind = Keyword.get(options, :bind, @default_bound_address)
    bbind = if bind != :any do
      case :inet.parse_address(to_charlist(bind)) do
		{:ok, bin} -> bin
		{_, error} -> usage("Invalid IP address \"#{bind}\": #{error}")
      end
    else
      bind
    end
    port = Keyword.get(options, :port, @default_port)
    level = Keyword.get(options, :level, @default_log_level)
    alevel = String.to_atom(level)
    Indian.accept(bbind, port, alevel)
  end

end
